<?php
// RADIUS SERVER CONFIG WIZARD
//
// Copyright (c) 2010 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: $

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// run the initialization function
radiusserver_configwizard_init();

function radiusserver_configwizard_init(){
	
	$name="radiusserver";
	
	$args=array(
		CONFIGWIZARD_NAME => $name,
        CONFIGWIZARD_VERSION => "1.2",
		CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
		CONFIGWIZARD_DESCRIPTION => gettext("Monitor a RADIUS server."),
		CONFIGWIZARD_DISPLAYTITLE => gettext("RADIUS Server"),
		CONFIGWIZARD_FUNCTION => "radiusserver_configwizard_func",
		CONFIGWIZARD_PREVIEWIMAGE => "globe4.png",
		);
		
	register_configwizard($name,$args);
	}



function radiusserver_configwizard_func($mode="",$inargs=null,&$outargs,&$result){

	$wizard_name="radiusserver";
	
	// initialize return code and output
	$result=0;
	$output="";
	
	// initialize output args - pass back the same data we got
	$outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;


	switch($mode){
		case CONFIGWIZARD_MODE_GETSTAGE1HTML:
		
			$address=grab_array_var($inargs,"address","");
			
			$output='

	<div class="sectionTitle">'.gettext('RADIUS Server').'</div>
	
			
	<table>

	<tr>
	<td valign="top">
	<label>'.gettext('Address').':</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="40" name="address" id="address" value="'.htmlentities($address).'" class="textfield" /><br class="nobr" />
	'.gettext('The IP address or FQDNS name of the device or server associated with the RADIUS server.').'<br><br>
	</td>
	</tr>

	</table>

			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address","");
			
			
			// check for errors
			$errors=0;
			$errmsg=array();
			if(have_value($address)==false)
				$errmsg[$errors++]=gettext("No address specified.");
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;
			
		case CONFIGWIZARD_MODE_GETSTAGE2HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");

			$ha=@gethostbyaddr($address);
			if($ha=="")
				$ha=$address;
			$hostname=grab_array_var($inargs,"hostname",$ha);
		
			$username=grab_array_var($inargs,"username");
			$password=grab_array_var($inargs,"password");
			$secret=grab_array_var($inargs,"secret");
			$port=grab_array_var($inargs,"port","1812");

			$services=grab_array_var($inargs,"services",array("server"=>"on","transfer"=>""));
			
		
			$output='
			
		<input type="hidden" name="address" value="'.htmlentities($address).'">

	<div class="sectionTitle">'.gettext('RADIUS Server').'</div>
	
			
	<table>
	
	<tr>
	<td valign="top">
	<label>'.gettext('Address').':</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="address" id="address" value="'.htmlentities($address).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Host Name').':</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="hostname" id="hostname" value="'.htmlentities($hostname).'" class="textfield" /><br class="nobr" />
	'.gettext('The name you\'d like to have associated with this RADIUS server.').'
	</td>
	</tr>
	
	</table>


	<div class="sectionTitle">'.gettext('Server Options').'</div>
	
	
	<table>
	
	<tr>
	<td valign="top">
	<label>'.gettext('Secret').':</label><br class="nobr" />
	</td>
	<td>
	<input type="password" size="16" name="secret" value="'.htmlentities($secret).'" class="textfield" /><br> 
	'.gettext('The shared secret to use when logging into the RADIUS server.').'<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Username').':</label><br class="nobr" />
	</td>
	<td>
	<input type="text" size="16" name="username" value="'.htmlentities($username).'" class="textfield" /><br> 
	'.gettext('The username used to login to the RADIUS server.').'<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Password').':</label><br class="nobr" />
	</td>
	<td>
	<input type="text" size="16" name="password" value="'.htmlentities($password).'" class="textfield" /><br> 
	'.gettext('The password used to login to the RADIUS server.').'<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Port').':</label><br class="nobr" />
	</td>
	<td>
	<input type="text" size="3" name="port" value="'.htmlentities($port).'" class="textfield" /><br> 
	'.gettext('The port number the RADIUS server runs on.').'<br><br>
	</td>
	</tr>

	</table>

			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$hostname=grab_array_var($inargs,"hostname");
			$username=grab_array_var($inargs,"username");
			$password=grab_array_var($inargs,"password");
			$secret=grab_array_var($inargs,"secret");
			$port=grab_array_var($inargs,"port");
			
			$services=grab_array_var($inargs,"services",array());
			
		
			// check for errors
			$errors=0;
			$errmsg=array();
			if(is_valid_host_name($hostname)==false)
				$errmsg[$errors++]=gettext("Invalid host name.");
			if($username=="" || $password=="")
				$errmsg[$errors++]=gettext("Username or password is blank.");
			if($secret=="")
				$errmsg[$errors++]=gettext("Secret is blank.");
			if($port=="")
				$errmsg[$errors++]=gettext("Invalid port number.");
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;

			
		case CONFIGWIZARD_MODE_GETSTAGE3HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$hostname=grab_array_var($inargs,"hostname");
			
			$username=grab_array_var($inargs,"username");
			$password=grab_array_var($inargs,"password");
			$secret=grab_array_var($inargs,"secret");
			$port=grab_array_var($inargs,"port");
			
			$services=grab_array_var($inargs,"services");
			$serviceargs=grab_array_var($inargs,"serviceargs");
		
			$output='
			
		<input type="hidden" name="address" value="'.htmlentities($address).'">
		<input type="hidden" name="hostname" value="'.htmlentities($hostname).'">
		<input type="hidden" name="username" value="'.htmlentities($username).'">
		<input type="hidden" name="secret" value="'.htmlentities($secret).'">
		<input type="hidden" name="password" value="'.htmlentities($password).'">
		<input type="hidden" name="port" value="'.htmlentities($port).'">
		<input type="hidden" name="services_serial" value="'.base64_encode(serialize($services)).'">
		<input type="hidden" name="serviceargs_serial" value="'.base64_encode(serialize($serviceargs)).'">
		
		<!--SERVICES='.serialize($services).'<BR>
		SERVICEARGS='.serialize($serviceargs).'<BR>-->
		
			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
				
			break;
			
		case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
			
			
			$output='
			';
			break;
			
		case CONFIGWIZARD_MODE_GETOBJECTS:
		
			$hostname=grab_array_var($inargs,"hostname","");
			$address=grab_array_var($inargs,"address","");
			$hostaddress=$address;
			
			$username=grab_array_var($inargs,"username");
			$password=grab_array_var($inargs,"password");
			$secret=grab_array_var($inargs,"secret");
			$port=grab_array_var($inargs,"port");
			
			$services_serial=grab_array_var($inargs,"services_serial","");
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial","");
			
			$services=unserialize(base64_decode($services_serial));
			$serviceargs=unserialize(base64_decode($serviceargs_serial));
			
			/*
			echo "SERVICES<BR>";
			print_r($services);
			echo "<BR>";
			echo "SERVICEARGS<BR>";
			print_r($serviceargs);
			echo "<BR>";
			*/
			
			// save data for later use in re-entrance
			$meta_arr=array();
			$meta_arr["hostname"]=$hostname;
			$meta_arr["address"]=$address;
			$meta_arr["username"]=$username;
			$meta_arr["password"]=$password;
			$meta_arr["secret"]=$secret;
			$meta_arr["port"]=$port;
			$meta_arr["services"]=$services;
			$meta_arr["serivceargs"]=$serviceargs;
			save_configwizard_object_meta($wizard_name,$hostname,"",$meta_arr);			
			
			$objs=array();
			
			if(!host_exists($hostname)){
				$objs[]=array(
					"type" => OBJECTTYPE_HOST,
					"use" => "xiwizard_radiusserver_host",
					"host_name" => $hostname,
					"address" => $hostaddress,
					"icon_image" => "globe4.png",
					"statusmap_image" => "globe4.png",
					"_xiwizard" => $wizard_name,
					);
				}
				
			$pluginopts="";
			$pluginopts.="-u \"".$username."\" -p \"".$password."\" -s \"".$secret."\"";
				
			$objs[]=array(
				"type" => OBJECTTYPE_SERVICE,
				"host_name" => $hostname,
				"service_description" => "RADIUS Server",
				"use" => "xiwizard_radiusserver_radius_service",
				"check_command" => "check_radius_server_adv!".$pluginopts,
				"_xiwizard" => $wizard_name,
				"icon_image" => "globe4.png",
				);
				
			//echo "OBJECTS:<BR>";
			//print_r($objs);
			//exit();
					
			// return the object definitions to the wizard
			$outargs[CONFIGWIZARD_NAGIOS_OBJECTS]=$objs;
		
			break;
			
		default:
			break;			
		}
		
	return $output;
	}
	

?>